#!/usr/bin/env cwl-runner

cwlVersion: v1.2
class: CommandLineTool

label: "Gene prediction"

doc: |
    Runs microbial gene prediction on GBOL RDF file

requirements:
 - class: InlineJavascriptRequirement

inputs:
  input:
    type: File
    doc: Reference genome file used in RDF format
    label: Reference genome
    inputBinding:
      prefix: -input
  codon:
    type: int
    doc: Codon table to be used
    label: Codon table
    inputBinding:
      prefix: -codon
  # output:
  #   type: string
  #   doc: Output file for prodigal annotation
  #   label: Output file
  #   inputBinding:
  #     prefix: -output
  single:
    type: boolean?
    doc: Input is a single genome
    inputBinding:
      prefix: -single
  meta:
    type: boolean?
    doc: Input is a meta-genome
    inputBinding:
      prefix: -meta
  identifier:
    type: string
    doc: Name of the sample being analysed
    label: Sample name

baseCommand: ["java", "-Xmx5g", "-jar", "/unlock/infrastructure/binaries/sapp/genecaller.jar", "-prodigal"]

arguments:
  - prefix: "-output"
    valueFrom: $(inputs.identifier).prodigal.ttl

outputs:
  output: 
    type: File
    outputBinding:
      glob: $(inputs.identifier).prodigal.ttl


s:author:
  - class: s:Person
    s:identifier: https://orcid.org/0000-0001-8172-8981
    s:email: mailto:jasper.koehorst@wur.nl
    s:name: Jasper Koehorst
  - class: s:Person
    s:identifier: https://orcid.org/0000-0001-9524-5964
    s:email: mailto:bart.nijsse@wur.nl
    s:name: Bart Nijsse

s:citation: https://m-unlock.nl
s:codeRepository: https://gitlab.com/m-unlock/cwl
s:dateCreated: "2020-00-00"
s:license: https://spdx.org/licenses/Apache-2.0 
s:copyrightHolder: "UNLOCK - Unlocking Microbial Potential"


$namespaces:
  s: https://schema.org/
  edam: http://edamontology.org/

$schemas:
 - http://edamontology.org/EDAM_1.18.owl